@@ -18,11 +18,10 @@
 import os
 import sys
 import textwrap as _textwrap
-from argparse import SUPPRESS, ArgumentParser, HelpFormatter
-from os import environ as env
+from argparse import SUPPRESS, ArgumentParser, HelpFormatter, Namespace
 
 from gstore import __copyright__, __version__
-from gstore.client import DEFAULT_HOST, TOKEN_NAMES
+from gstore import env
 
 
 class LineBreaksFormatter(HelpFormatter):
@@ -37,8 +36,7 @@ class LineBreaksFormatter(HelpFormatter):
 
     This help formatter allows for you to optional enable/toggle raw text on
     individual menu items by prefixing the help string with 'n|'."""
-
-    def _fill_text(self, text, width, indent):
+    def _fill_text(self, text, width, indent) -> str:
         text = self._whitespace_matcher.sub(' ', text).strip()
         paragraphs = text.split('|n ')
 
@@ -57,7 +55,7 @@ class LineBreaksFormatter(HelpFormatter):
         return multiline_text
 
 
-def get_version_str():
+def get_version_str() -> str:
     """A helper function to format version info."""
     version = '''
     {prog}s {version}|n
@@ -72,38 +70,20 @@ def get_version_str():
     return version
 
 
-def get_token_from_env():
-    """Get authentication token for GitHub API from environment variables.
-
-    The order of searching for a token in environment variables:
-    * GH_TOKEN, GITHUB_TOKEN (in order of precedence)
-    * GH_ENTERPRISE_TOKEN, GITHUB_ENTERPRISE_TOKEN (in order of precedence)
-
-    :returns: An authentication token for github.com API requests
-    :rtype: str or None
-    """
-    for name in TOKEN_NAMES:
-        token = env.get(name)
-        if token:
-            return token
-
-    return None
-
-
-def parser_add_positionals(parser: ArgumentParser):
-    """Adds positional parameters group to a parser."""
+def parser_add_positionals(parser: ArgumentParser) -> ArgumentParser:
+    """Add positional parameters group to a parser."""
     pgroup = parser.add_argument_group('Positional parameters')
 
     pgroup.add_argument('target', nargs='?', type=str,
-                        default=env.get('GSTORE_DIR', os.getcwd()),
+                        default=env.get_target() or os.getcwd(),
                         help='Base target to sync repos (e.g. folder on disk)')
 
     return parser
 
 
-def parser_add_options(parser: ArgumentParser):
-    """Adds options group to a parser."""
-    token = get_token_from_env()
+def parser_add_options(parser: ArgumentParser) -> ArgumentParser:
+    """Add options group to a parser."""
+    token = env.lookup_token()
 
     ogroup = parser.add_argument_group('Options')
 
@@ -113,9 +93,8 @@ def parser_add_options(parser: ArgumentParser):
     ogroup.add_argument('--token', dest='token', default=token, type=str,
                         help='An authentication token for GitHub API requests')
 
-    ogroup.add_argument('--host', dest='host',
-                        default=env.get('GH_HOST', DEFAULT_HOST), type=str,
-                        help='The GitHub API hostname')
+    ogroup.add_argument('--host', dest='host', default=env.lookup_token(),
+                        type=str, help='The GitHub API hostname')
 
     ogroup.add_argument('-o', '--org', dest='org', action='append', type=str,
                         help='Organization to sync (all if not provided)')
@@ -141,8 +120,10 @@ def parser_add_options(parser: ArgumentParser):
     ogroup.add_argument('-dumpversion', action='version',
                         help=dumpversion_help, version=__version__)
 
+    return parser
 
-def argparse():
+
+def argparse() -> Namespace or None:
     """
     The function initializes command line arguments parser.
 
@@ -163,7 +144,7 @@ def argparse():
     parser_add_positionals(parser)
     parser_add_options(parser)
 
-    if len(sys.argv) == 1 and get_token_from_env() is None:
+    if len(sys.argv) == 1 and env.lookup_token() is None:
         parser.print_help(sys.stderr)
         return None
 
