@@ -16,23 +16,24 @@
 """The CLI entry point. Invoke as `gstore' or `python -m gstore'."""
 
 import logging
+import signal
+import sys
 
 from gstore.args import argparse
 from gstore.client import Client
+from gstore.exceptions import Error
 from gstore.logger import setup_logger
 from gstore.repo import RepoManager
-from gstore.exceptions import BaseValidationError
 
 
 def main():
-    """
-    The main function to call gstore from the command line.
+    """The main function to call gstore from the command line.
 
     :return: An exit code
     :rtype: int
     """
     args = argparse()
-    retval = 0
+    retval = int(args is None)
 
     if args:
         setup_logger(verbose=args.verbose, quiet=args.quiet)
@@ -55,8 +56,14 @@ def main():
                     repos = client.resolve_repos(args.repo, org)
 
                 manager.sync(org, repos)
-        except BaseValidationError as gstore_exception:
-            logger.error(gstore_exception)
+        except KeyboardInterrupt:  # the user hit control-C
+            sys.stderr.write('Received keyboard interrupt, terminating.\n')
+            sys.stderr.flush()
+            # Control-C is fatal error signal 2, for more see
+            # https://tldp.org/LDP/abs/html/exitcodes.html
+            retval = 128 + signal.SIGINT
+        except Error as gstore_error:
+            logger.error(gstore_error)
             retval = 1
 
     return retval
