@@ -25,7 +25,7 @@ from github.GithubException import BadCredentialsException
 from github.GithubException import UnknownObjectException
 
 from gstore import __version__
-from gstore.exceptions import InvalidCredentialsError
+from gstore.exceptions import Error
 from gstore.models import Organization, Repository
 
 USER_AGENT = f'Gstore/{__version__}'
@@ -33,23 +33,27 @@ USER_AGENT = f'Gstore/{__version__}'
 DEFAULT_HOST = 'api.github.com'
 DEFAULT_TIMEOUT = 15
 
-TOKEN_NAMES = (
-    'GH_TOKEN',
-    'GITHUB_TOKEN',
-    'GH_ENTERPRISE_TOKEN',
-    'GITHUB_ENTERPRISE_TOKEN',
-)
+
+class ValidationError(Error):
+    """Base validation error."""
+
+
+class InvalidCredentialsError(Error):
+    """An error resulting from the use of incorrect credentials."""
+
+    def __init__(self):
+        message = 'The token provided to access the GitHub API is invalid'
+        super().__init__(message)
 
 
 class Client:
-    """
-    This is a wrapper class around :class:`github.Github` to interact with
+    """A wrapper class around :class:`github.Github` to interact with
     GitHub API.
 
     :param str token: Authentication token for github.com API requests
     :param str api_host: Default base URL for github.com API requests
     :param int timeout: Timeout for HTTP requests
-    :raise InvalidCredentialsError: in case of GitHub token is not provided.
+    :raises ValidationError: in case of GitHub token is not provided.
     """
 
     def __init__(
@@ -60,9 +64,14 @@ class Client:
     ):
         self.logger = logging.getLogger('gstore.client')
 
+        # The use case with Client(token='...', api_host=None)
+        if not api_host:
+            api_host = DEFAULT_HOST
+
+        # The use case with Client(token=None)
         if not token:
-            raise InvalidCredentialsError(
-                'GitHub token is not provided or it is empty')
+            raise ValidationError(
+                'Missing parameter: GitHub Token is required')
 
         api_url = 'https://{}'.format(api_host)
         self.logger.debug('Setting API URL to %s', api_url)
@@ -75,8 +84,7 @@ class Client:
         )
 
     def get_repos(self, org: Organization):
-        """
-        Getting organization repositories.
+        """Get organization repositories.
 
         :param Organization org: User's organization
         :return: A collection with repositories
@@ -103,8 +111,7 @@ class Client:
         return retval
 
     def resolve_repos(self, repos: list, org: Organization):
-        """
-        Resolve repositories from provided list.
+        """Resolve repositories from provided list.
 
         :param list repos: A list of repositories in form 'org:repo'
         :param Organization org: User's organization
@@ -140,42 +147,42 @@ class Client:
                 self.logger.error('Invalid repository name "%s"', repo_name)
                 continue
             except BadCredentialsException as bad_credentials:
-                raise InvalidCredentialsError(
-                    'Bad token was used when accessing the GitHub API'
-                ) from bad_credentials
+                raise InvalidCredentialsError() from bad_credentials
 
         return retval
 
     def get_orgs(self):
-        """
-        Getting organizations for a user.
+        """Get organizations for a user.
 
+        :raises InvalidCredentialsError: in case of bad credentials.
         :returns: A collection with organizations
         :rtype: list of :class:`gstore.models.Organization`
         """
         self.logger.info('Getting organizations for user')
 
-        user = self.github.get_user()
-        orgs = user.get_orgs()
+        try:
+            user = self.github.get_user()
+            orgs = user.get_orgs()
 
-        self.logger.info(
-            'Number of available organizations for %s user: %s',
-            user.login,
-            orgs.totalCount
-        )
+            self.logger.info(
+                'Number of available organizations for %s user: %s',
+                user.login,
+                orgs.totalCount
+            )
 
-        retval = []
-        for org in orgs:
-            retval.append(Organization(org.login))
+            retval = []
+            for org in orgs:
+                retval.append(Organization(org.login))
 
-        return retval
+            return retval
+        except BadCredentialsException as bad_credentials:
+            raise InvalidCredentialsError() from bad_credentials
 
     def resolve_orgs(self, orgs: list):
-        """
-        Resolve organizations from provided list.
+        """Resolve organizations from provided list.
 
         :param list orgs: A list of organizations names
-        :raise InvalidCredentialsError: in case of bad credentials.
+        :raises InvalidCredentialsError: in case of bad credentials.
         :return: A collection with organizations
         :rtype: list of :class:`gstore.models.Organization`
         """
@@ -193,8 +200,6 @@ class Client:
                 self.logger.error('Invalid organization name "%s"', name)
                 continue
             except BadCredentialsException as bad_credentials:
-                raise InvalidCredentialsError(
-                    'Bad token was used when accessing the GitHub API'
-                ) from bad_credentials
+                raise InvalidCredentialsError() from bad_credentials
 
         return retval
