@@ -31,8 +31,7 @@ class RepoProgressPrinter(git.RemoteProgress):
     """
 
     def update(self, op_code, cur_count, max_count=None, message=''):
-        """
-        Called whenever the progress changes
+        """Called whenever the progress changes.
 
         :param op_code:
             Integer allowing to be compared against Operation IDs and stage
@@ -112,6 +111,14 @@ class RepoManager:
         self.logger.debug('Initialize repository instance')
         local_repo = git.Repo(target)
 
+        if len(local_repo.heads) == 0:
+            self.logger.info(
+                'There are no remote branches for %s/%s, skip updating',
+                repo.org.login,
+                repo.name
+            )
+            return
+
         try:
             self.logger.debug('Download objects and refs from repository')
             local_repo.git.fetch(['--prune', '--quiet'])
@@ -159,7 +166,7 @@ class RepoManager:
                     )
                     continue
 
-                # We're plan to run a Git command, but weren't inside a
+                # We're going to run a Git command, but weren't inside a
                 # local Git repository.
                 if not os.path.exists(git_path):
                     self.logger.debug(
