@@ -13,13 +13,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this file.  If not, see <https://www.gnu.org/licenses/>.
 
+import logging
 from unittest import mock
 
 import pytest
 from github.GithubException import UnknownObjectException
 
-from gstore.client import Client
-from gstore.exceptions import InvalidCredentialsError
+from gstore.client import Client, ValidationError, InvalidCredentialsError
+from gstore.client import DEFAULT_HOST
 from gstore.models import Organization, Repository
 
 
@@ -27,15 +28,29 @@ from gstore.models import Organization, Repository
 def test_empty_token(token):
     """Call Client() with empty token should raise exception."""
     with pytest.raises(
-            InvalidCredentialsError,
-            match='GitHub token is not provided or it is empty'):
+            ValidationError,
+            match='Missing parameter: GitHub Token is required'):
         Client(token)
 
 
-def test_resolve_orgs_empty_list():
-    """Call Client.resolve_orgs() with empty list should return empty list."""
-    client = Client('secret')
+@pytest.mark.parametrize(
+    'provided,expected',
+    [
+        (None, f'https://{DEFAULT_HOST}'),
+        ('', f'https://{DEFAULT_HOST}'),
+        ('github.example.com', 'https://github.example.com'),
+    ]
+)
+def test_setting_host(provided, expected, monkeypatch):
+    """Call Client() with empty api_host will use default host."""
+    with mock.patch.object(logging.Logger, 'debug') as mock_logger:
+        Client(token='secret', api_host=provided)
+        mock_logger.assert_called_once_with(
+            'Setting API URL to %s', expected)
 
+
+def test_resolve_orgs_empty_list(client):
+    """Call Client.resolve_orgs() with empty list should return empty list."""
     with mock.patch.object(client.logger, 'info') as mock_logger:
         orgs = client.resolve_orgs([])
 
@@ -44,16 +59,13 @@ def test_resolve_orgs_empty_list():
             'Resolve organizations from provided configuration')
 
 
-def test_resolve_orgs_unknown_org(monkeypatch):
-    """
-    Call Client.resolve_orgs() for a non existent organization will not stop
-    work but we'll see an error in the logs.
+def test_resolve_orgs_unknown_org(monkeypatch, client):
+    """Call Client.resolve_orgs() for a non-existent organization will not stop
+    work, but we'll see an error in the logs.
     """
     def mock_get_organization(_):
         raise UnknownObjectException(401, 'Not found')
 
-    client = Client('secret')
-
     monkeypatch.setattr(
         client.github,
         'get_organization',
@@ -68,13 +80,10 @@ def test_resolve_orgs_unknown_org(monkeypatch):
             'Invalid organization name "%s"', 'foo-bar-baz')
 
 
-def test_resolve_orgs(mock_micro_organization):
-    """
-    Call Client.resolve_orgs() with a non empty list of organization names
+def test_resolve_orgs(mock_micro_organization, client):
+    """Call Client.resolve_orgs() with a non-empty list of organization names
     will return a list of :class:`gstore.models.Organization`
     """
-    client = Client('secret')
-
     orgs = client.resolve_orgs(['awesome', 'company'])
 
     assert len(orgs) == 2
@@ -84,29 +93,23 @@ def test_resolve_orgs(mock_micro_organization):
     assert orgs[1].login == 'company'
 
 
-def test_resolve_orgs_invalid_token():
+def test_resolve_orgs_invalid_token(client):
     """Call Client.resolve_orgs() with invalid token."""
-    client = Client('secret')
-
     with pytest.raises(
             InvalidCredentialsError,
-            match='Bad token was used when accessing the GitHub API'):
+            match='The token provided to access the GitHub API is invalid'):
         client.resolve_orgs(['github'])
 
 
-def test_resolve_repos_empty_list():
-    """
-    Call Client.resolve_repos() with empty repo list or not expected org
+def test_resolve_repos_empty_list(client, organization):
+    """Call Client.resolve_repos() with empty repo list or not expected org
     should return empty list.
     """
-    client = Client('secret')
-    fake_org = Organization('fake_org')
-
     with mock.patch.object(client.logger, 'info') as mock_logger:
-        repos = client.resolve_repos([], fake_org)
+        repos = client.resolve_repos([], organization)
         assert len(repos) == 0
 
-        repos = client.resolve_repos(['foo:bar'], fake_org)
+        repos = client.resolve_repos(['foo:bar'], organization)
         assert len(repos) == 0
 
         mock_logger.assert_called_with(
@@ -114,13 +117,10 @@ def test_resolve_repos_empty_list():
         )
 
 
-def test_get_orgs_empty_list(mock_user):
-    """
-    Call Client.get_orgs() for a user without organizations will return an
+def test_get_orgs_empty_list(mock_user, client):
+    """Call Client.get_orgs() for a user without organizations will return an
     empty list.
     """
-    client = Client('secret')
-
     with mock.patch.object(client.logger, 'info') as mock_logger:
         orgs = client.get_orgs()
         assert len(orgs) == 0
@@ -137,12 +137,10 @@ def test_get_orgs_empty_list(mock_user):
         mock_logger.assert_has_calls(calls)
 
 
-def test_get_orgs(mock_user, mock_orgs_iter):
-    """
-    Call Client.get_orgs() for a user will return a list of
+def test_get_orgs(mock_user, mock_orgs_iter, client):
+    """Call Client.get_orgs() for a user will return a list of
     :class:`gstore.models.Organization`
     """
-    client = Client('secret')
     orgs = client.get_orgs()
 
     assert len(orgs) == 2
@@ -152,13 +150,10 @@ def test_get_orgs(mock_user, mock_orgs_iter):
     assert orgs[1].login == 'company'
 
 
-def test_resolve_repos_unknown_org(mock_organization, mock_repository):
+def test_resolve_repos_unknown_org(mock_organization, mock_repository, client):
+    """Call Client.resolve_repos() for a non-existent repository will not stop
+    work, but we'll see an error in the logs.
     """
-    Call Client.resolve_repos() for a non existent repository will not stop
-    work but we'll see an error in the logs.
-    """
-    client = Client('secret')
-
     with mock.patch.object(client.logger, 'error') as mock_logger:
         repos = client.resolve_repos(
             ['Acme:secret-repo'],
@@ -170,15 +165,11 @@ def test_resolve_repos_unknown_org(mock_organization, mock_repository):
             'Invalid repository name "%s"', 'secret-repo')
 
 
-def test_resolve_repos(mock_organization):
-    """
-    Call Client.resolve_orgs() with a non empty list of repo patterns
+def test_resolve_repos(mock_organization, client, organization):
+    """Call Client.resolve_orgs() with a non-empty list of repo patterns
     will return a list of :class:`gstore.models.Repository`
     """
-    org = Organization('Acme')
-    client = Client('secret')
-
-    repos = client.resolve_repos(['Acme:awesome', 'Acme:repo'], org)
+    repos = client.resolve_repos(['Acme:awesome', 'Acme:repo'], organization)
 
     assert len(repos) == 2
     assert isinstance(repos[0], Repository)
@@ -187,49 +178,40 @@ def test_resolve_repos(mock_organization):
     assert repos[1].name == 'repo'
 
 
-def test_resolve_repos_invalid_token():
+def test_resolve_repos_invalid_token(client):
     """Call Client.resolve_repos() with invalid token."""
-    client = Client('secret')
-
     with pytest.raises(
             InvalidCredentialsError,
-            match='Bad token was used when accessing the GitHub API'):
+            match='The token provided to access the GitHub API is invalid'):
         client.resolve_repos(['Acme:github'], Organization('Acme'))
 
 
 @pytest.mark.parametrize('repo', ['', ':', 'a', 'a:', 'a:b:', 'a:b:c'])
-def test_resolve_repos_invalid_repo_pattern(repo):
-    """
-    Call Client.resolve_repos() with invalid repo pattern
+def test_resolve_repos_invalid_repo_pattern(repo, client, organization):
+    """Call Client.resolve_repos() with invalid repo pattern
     should return empty list and log error.
     """
-    client = Client('secret')
-    fake_org = Organization('fake_org')
-
     with mock.patch.object(client.logger, 'error') as mock_logger:
-        repos = client.resolve_repos([repo], fake_org)
+        repos = client.resolve_repos([repo], organization)
 
         assert len(repos) == 0
         mock_logger.assert_called_once_with(
             'Invalid repo pattern: "%s", skip resolving', repo)
 
 
-def test_get_repos_empty_list(mock_organization):
+def test_get_repos_empty_list(mock_organization, client, organization):
+    """Call Client.get_repos() for an organization without repositories will
+    return an empty list.
     """
-    Call Client.get_repos() for a organization without repositories will return
-    an empty list.
-    """
-    client = Client('secret')
-
     with mock.patch.object(client.logger, 'info') as mock_logger:
-        repos = client.get_repos(Organization('awesome'))
+        repos = client.get_repos(organization)
         assert len(repos) == 0
 
         calls = [
             mock.call('Getting repositories for organization'),
             mock.call(
                 'Number of available repositories for %s organization: %s',
-                'awesome',
+                'Acme',
                 0
             ),
         ]
@@ -237,12 +219,10 @@ def test_get_repos_empty_list(mock_organization):
         mock_logger.assert_has_calls(calls)
 
 
-def test_get_repos(mock_organization, mock_repos_iter):
+def test_get_repos(mock_organization, mock_repos_iter, client):
+    """Call Client.get_repos() for an organization will return a list of
+    gstore.models.Repository.
     """
-    Call Client.get_repos() for an organization will return a list of
-    :class:`gstore.models.Repository`
-    """
-    client = Client('secret')
     repos = client.get_repos(Organization('awesome'))
 
     assert len(repos) == 2
